==> jc-1.4.0.tar.gz: soot/jimple/toolkits/typing/ClassHierarchy.h <==
// class soot.jimple.toolkits.typing.ClassHierarchy

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e6ab0f7d82decbbb soot_jimple_toolkits_typing_ClassHierarchy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_typing_ClassHierarchy_H_
#define _JC_soot_jimple_toolkits_typing_ClassHierarchy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_soot_Scene$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object;
struct _jc_soot_jimple_toolkits_typing_TypeNode$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object	_jc_soot_jimple_toolkits_typing_ClassHierarchy$object;

typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy$method$_init$3578fb7d7f1b1d84(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *, struct _jc_soot_Scene$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *);
extern struct _jc_soot_jimple_toolkits_typing_TypeNode$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy$method$typeNode$2287374c8124fdda(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy$method_info$typeNode$2287374c8124fdda;

// Static methods
extern struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy$method$classHierarchy$974477d7c747383d(_jc_env *, struct _jc_soot_Scene$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *);
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*(*typeNode$2287374c8124fdda)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods	soot_jimple_toolkits_typing_ClassHierarchy;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs {
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*OBJECT;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*CLONEABLE;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*SERIALIZABLE;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*NULL;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*INT;
	struct _jc_soot_Scene$object	*scene;
	struct _jc_object	*typeNodeList;
	struct _jc_java_util_HashMap$object	*typeNodeMap;
	struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object	*transform;
	struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object	*make;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$refs {
    _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs	soot_jimple_toolkits_typing_ClassHierarchy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs	soot_jimple_toolkits_typing_ClassHierarchy;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object {
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype _jc_soot_jimple_toolkits_typing_ClassHierarchy$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_ClassHierarchy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_ClassHierarchy$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_ClassHierarchy_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/typing/ClassHierarchy.h <==
// class soot.jimple.toolkits.typing.ClassHierarchy

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e6ab0f7d82decbbb soot_jimple_toolkits_typing_ClassHierarchy

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_typing_ClassHierarchy_H_
#define _JC_soot_jimple_toolkits_typing_ClassHierarchy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_soot_Scene$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object;
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object;
struct _jc_soot_jimple_toolkits_typing_TypeNode$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$refs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$refs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs	_jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object	_jc_soot_jimple_toolkits_typing_ClassHierarchy$object;

typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_ClassHierarchy$method$_init$3578fb7d7f1b1d84(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *, struct _jc_soot_Scene$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_typing_TypeNode$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy$method$typeNode$2287374c8124fdda(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_toolkits_typing_ClassHierarchy$method_info$typeNode$2287374c8124fdda;

// Static methods
extern struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *_jc_soot_jimple_toolkits_typing_ClassHierarchy$method$classHierarchy$974477d7c747383d(_jc_env *, struct _jc_soot_Scene$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*(*typeNode$2287374c8124fdda)(_jc_env *, struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vmethods	soot_jimple_toolkits_typing_ClassHierarchy;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs {
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*OBJECT;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*CLONEABLE;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*SERIALIZABLE;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*NULL;
	struct _jc_soot_jimple_toolkits_typing_TypeNode$object	*INT;
	struct _jc_soot_Scene$object	*scene;
	struct _jc_object	*typeNodeList;
	struct _jc_java_util_HashMap$object	*typeNodeMap;
	struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ToInt$object	*transform;
	struct _jc_soot_jimple_toolkits_typing_ClassHierarchy__24ConstructorChooser$object	*make;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$refs {
    _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_refs	soot_jimple_toolkits_typing_ClassHierarchy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_typing_ClassHierarchy$sub_nonrefs	soot_jimple_toolkits_typing_ClassHierarchy;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_ClassHierarchy$object {
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_ClassHierarchy$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_ClassHierarchy$vtype _jc_soot_jimple_toolkits_typing_ClassHierarchy$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_ClassHierarchy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_ClassHierarchy$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_ClassHierarchy_H_ */
